@@ -161,45 +161,65 @@ meltt <- function(...,taxonomies,twindow,spatwindow,smartmatch=TRUE,certainty=NA
   }
   for (dat in 1:length(datasets)){
     if (!is.element('date',names(eval(datasets[[dat]])))){
-      missing_arguments <- append(missing_arguments,paste0('\n  data: date column(s) are missing in ',as.character(datasets[[dat]]),''))
+      missing_arguments <- append(missing_arguments,paste0("\n  data: date column(s) are missing in ',as.character(datasets[[dat]]),'"))
       terminate <- TRUE
     }else{
-      if(class(as.data.frame(eval(datasets[[dat]]))[,'date'])!="Date"){
+      date_col = as.data.frame(eval(datasets[[dat]]))[,'date']
+      if(class(date_col)!="Date"){
         missing_arguments <- append(missing_arguments,
-                                    paste0('\n  data: date column in ',
-                                           as.character(datasets[[dat]]),
-                                           " is not of class 'Date' or is not formatted as 'yyyy-mm-dd'"))
+                                    paste0("\n  data: date column in '",as.character(datasets[[dat]]),"' is not of class 'Date'"))
+        terminate <- TRUE
+      }
+      datecheck <- try(as.Date(date_col, format= "%Y-%m-%d %H:%M:%S"))
+      if (any(class(datecheck) == "try-error" || is.na(datecheck))){
+        missing_arguments <- append(missing_arguments,paste0("\n  data: 'date' column in '",as.character(datasets[[dat]]),
+                                                             "' must be formatted as 'YYYY-MM-DD hh:mm:ss'\n"))
+        terminate <- TRUE
+      }
+      if (any(is.na(date_col))){
+        missing_arguments <- append(missing_arguments,paste0("\n  data: date column in '",as.character(datasets[[dat]]),
+                                                             "' must be well-defined for all entries ('NA' values exist)\n"))
         terminate <- TRUE
       }
     }
     if (!is.element('enddate',names(eval(datasets[[dat]]))) & enddate_check){
-      warning_arguments <- append(warning_arguments,paste0("\nOne or more of the input datasets contains episodal data but no 'enddate' varible was specified for dataset '",as.character(datasets[[dat]]),
+      warning_arguments <- append(warning_arguments,paste0("\n  One or more of the input datasets contains episodal data but no 'enddate' varible was specified for dataset '",as.character(datasets[[dat]]),
                                                            "'. If an end date variable exists, please relabel as 'enddate'.\n"))
     }
     if (!is.element('latitude',names(eval(datasets[[dat]])))){
-      missing_arguments <- append(missing_arguments,paste0('\n  data: latitude column is missing in ',as.character(datasets[[dat]]),''))
+      missing_arguments <- append(missing_arguments,paste0("\n  data: latitude column is missing in '",as.character(datasets[[dat]]),"'\n"))
       terminate <- TRUE
     } else{
-      if(class(as.data.frame(eval(datasets[[dat]]))[,'latitude'])!="numeric"){
+      if(!is.numeric(as.data.frame(eval(datasets[[dat]]))[,'latitude'])){
         missing_arguments <- append(missing_arguments,paste0('\n  data: latitude column in ',as.character(datasets[[dat]]),
-                                                             " is not class 'Numeric' \n"))
+                                                             "' is not class 'Numeric' \n"))
+        terminate <- TRUE
+      }
+      if(any(is.na(as.data.frame(eval(datasets[[dat]]))[,'latitude']))){
+        missing_arguments <- append(missing_arguments,paste0("\n  data: latitude column in '",as.character(datasets[[dat]]),
+                                                             "' must be well-defined for all entries ('NA' values exist)\n"))
         terminate <- TRUE
       }
     }
     if (!is.element('longitude',names(eval(datasets[[dat]])))){
-      missing_arguments <- append(missing_arguments,paste0('\n  data: longitude column is missing in ',as.character(datasets[[dat]]),''))
+      missing_arguments <- append(missing_arguments,paste0("\n  data: longitude column is missing in ',as.character(datasets[[dat]]),'"))
       terminate <- TRUE
     } else{
-      if(class(as.data.frame(eval(datasets[[dat]]))[,'longitude'])!="numeric"){
-        missing_arguments <- append(missing_arguments,paste0('\n  data: longitude column in ',as.character(datasets[[dat]]),
-                                                             " is not class 'Numeric'"))
+      if(!is.numeric(as.data.frame(eval(datasets[[dat]]))[,'longitude'])){
+        missing_arguments <- append(missing_arguments,paste0("\n  data: longitude column in '",as.character(datasets[[dat]]),
+                                                             "' is not class 'Numeric'"))
+        terminate <- TRUE
+      }
+      if(any(is.na(as.data.frame(eval(datasets[[dat]]))[,'longitude']))){
+        missing_arguments <- append(missing_arguments,paste0("\n  data: longitude column in '",as.character(datasets[[dat]]),
+                                                             "' must be well-defined for all entries ('NA' values exist)\n"))
         terminate <- TRUE
       }
     }
   }
   if (terminate){ # Stop the function and print warnings
     missing_arguments <- append(unique(missing_arguments)," \n\n")
-    message("The following required arguments of meltt() are MISSING or MIS-SPECIFIED:", missing_arguments)
+    message("\n\nThe following required arguments of meltt() are MISSING or MIS-SPECIFIED:\n", missing_arguments)
     stop("meltt(...,taxonomies,twindow,spatwindow)) was not executed!", call.=FALSE)
   }else{
     cat('Done.\n')
